.. :changelog:

History
-------

develop (unreleased)
--------------------

0.3.0 (2018-01-26)
------------------

* Enforce Python 3.5 >= only in setup.py
* Add PublishExpireMixin and PublishExpireQuerySet

0.2.1 (2018-01-24)
------------------

* Re-upload to PyPI with an all lowercase name.

0.2.0 (2018-01-24)
------------------

* Add AutoIntVersionAdmin

0.1.0 (2018-01-22)
------------------

* Add SoftDeletionMixin
* Add AutoIntVersionMixin and AutoIntVersionField
* Add CreatedUpdatedMixin, CreatedUpdatedSerializer and CreatedUpdatedAdmin
* Add exception utils: raise_truthy, raise_falsey, raise_none
* Add testing.client.JSONClient

0.0.0 (2018-01-12)
------------------

* Initial commit.
